@@ -17,15 +17,12 @@ import os
 import sys
 from logging import getLogger
 
-from six.moves.urllib.parse import urlparse
-
 import Products
 import transaction
 from AccessControl import ClassSecurityInfo
 from AccessControl.class_init import InitializeClass
 from AccessControl.Permission import ApplicationDefaultPermissions
 from AccessControl.Permissions import view_management_screens
-from AccessControl.tainted import TaintedString
 from Acquisition import aq_base
 from App import FactoryDispatcher
 from App.ApplicationManager import ApplicationManager
@@ -104,53 +101,10 @@ class Application(ApplicationDefaultPermissions, Folder.Folder, FindSupport):
         # available as url.
         if destination.find('//') >= 0:
             raise RedirectException(destination)
-        raise RedirectException("%s/%s" % (URL1, destination))
+        raise RedirectException(f"{URL1}/{destination}")
 
     ZopeRedirect = Redirect
 
-    @security.protected(view_management_screens)
-    def getZMIMainFrameTarget(self, REQUEST):
-        """Utility method to get the right hand side ZMI frame source URL
-
-        For cases where JavaScript is disabled the ZMI uses a simple REQUEST
-        variable ``came_from`` to set the source URL for the right hand side
-        ZMI frame. Since this value can be manipulated by the user it must be
-        sanity-checked first.
-        """
-        parent_url = REQUEST['URL1']
-        default = '{}/manage_workspace'.format(parent_url)
-        came_from = REQUEST.get('came_from', None)
-
-        if not came_from:
-            return default
-
-        # When came_from contains suspicious code, it will not be a string,
-        # but an instance of AccessControl.tainted.TaintedString.
-        # Passing this to urlparse, gives:
-        # AttributeError: 'str' object has no attribute 'decode'
-        # This is good, but let's check explicitly.
-        if isinstance(came_from, TaintedString):
-            return default
-        try:
-            parsed_came_from = urlparse(came_from)
-        except AttributeError:
-            return default
-        parsed_parent_url = urlparse(parent_url)
-
-        # Only allow a passed-in ``came_from`` URL if it is local (just a path)
-        # or if the URL scheme and hostname are the same as our own
-        if (parsed_parent_url.scheme == parsed_came_from.scheme
-                and parsed_parent_url.netloc == parsed_came_from.netloc):
-            return came_from
-        if (not parsed_came_from.scheme and not parsed_came_from.netloc):
-            # This is only a path.  But some paths can be misinterpreted
-            # by browsers.
-            if parsed_came_from.path.startswith("//"):
-                return default
-            return came_from
-
-        return default
-
     def __bobo_traverse__(self, REQUEST, name=None):
         if name is None:
             # Make this more explicit, otherwise getattr(self, name)
@@ -170,8 +124,6 @@ class Application(ApplicationDefaultPermissions, Folder.Folder, FindSupport):
             pass
 
         method = REQUEST.get('REQUEST_METHOD', 'GET')
-        if NullResource is not None and method not in ('GET', 'POST'):
-            return NullResource(self, name, REQUEST).__of__(self)
 
         if method not in ('GET', 'POST'):
             return NullResource(self, name, REQUEST).__of__(self)
@@ -179,7 +131,7 @@ class Application(ApplicationDefaultPermissions, Folder.Folder, FindSupport):
         # Waaa. unrestrictedTraverse calls us with a fake REQUEST.
         # There is probably a better fix for this.
         try:
-            REQUEST.RESPONSE.notFoundError("%s\n%s" % (name, method))
+            REQUEST.RESPONSE.notFoundError(f"{name}\n{method}")
         except AttributeError:
             raise KeyError(name)
 
@@ -197,11 +149,9 @@ class Application(ApplicationDefaultPermissions, Folder.Folder, FindSupport):
         if major:
             return zversion.major
         else:
-            version = '%s.%s.%s' % (zversion.major,
-                                    zversion.minor,
-                                    zversion.micro)
+            version = f'{zversion.major}.{zversion.minor}.{zversion.micro}'
             if zversion.status:
-                version += '.%s%s' % (zversion.status, zversion.release)
+                version += f'.{zversion.status}{zversion.release}'
 
             return version
 
@@ -262,7 +212,7 @@ def initialize(app):
     initializer.initialize()
 
 
-class AppInitializer(object):
+class AppInitializer:
     """ Initialize an Application object (called at startup) """
 
     def __init__(self, app):
@@ -298,7 +248,7 @@ class AppInitializer(object):
             del app.__dict__['Control_Panel']
             app._objects = tuple(i for i in app._objects
                                  if i['id'] != 'Control_Panel')
-            self.commit(u'Removed persistent Control_Panel')
+            self.commit('Removed persistent Control_Panel')
 
     def install_required_roles(self):
         app = self.getApp()
@@ -306,13 +256,13 @@ class AppInitializer(object):
         # Ensure that Owner role exists.
         if hasattr(app, '__ac_roles__') and not ('Owner' in app.__ac_roles__):
             app.__ac_roles__ = app.__ac_roles__ + ('Owner',)
-            self.commit(u'Added Owner role')
+            self.commit('Added Owner role')
 
         # ensure the Authenticated role exists.
         if hasattr(app, '__ac_roles__'):
             if 'Authenticated' not in app.__ac_roles__:
                 app.__ac_roles__ = app.__ac_roles__ + ('Authenticated',)
-                self.commit(u'Added Authenticated role')
+                self.commit('Added Authenticated role')
 
     def install_inituser(self):
         app = self.getApp()
@@ -321,7 +271,7 @@ class AppInitializer(object):
             users = app.acl_users
             if hasattr(users, '_createInitialUser'):
                 app.acl_users._createInitialUser()
-                self.commit(u'Created initial user')
+                self.commit('Created initial user')
             users = aq_base(users)
             migrated = getattr(users, '_ofs_migrated', False)
             if not migrated:
@@ -335,7 +285,7 @@ class AppInitializer(object):
                     users._ofs_migrated = True
                     users._p_changed = True
                     app._p_changed = True
-                    transaction.get().note(u'Migrated user folder')
+                    transaction.get().note('Migrated user folder')
                     transaction.commit()
 
     def install_virtual_hosting(self):
@@ -349,7 +299,7 @@ class AppInitializer(object):
                 vhm = VirtualHostMonster()
                 vhm.id = 'virtual_hosting'
                 vhm.addToContainer(app)
-                self.commit(u'Added virtual_hosting')
+                self.commit('Added virtual_hosting')
 
     def install_root_view(self):
         app = self.getApp()
@@ -357,9 +307,9 @@ class AppInitializer(object):
             from Products.PageTemplates.ZopePageTemplate import \
                 ZopePageTemplate
             root_pt = ZopePageTemplate('index_html')
-            root_pt.pt_setTitle(u'Auto-generated default page')
+            root_pt.pt_setTitle('Auto-generated default page')
             app._setObject('index_html', root_pt)
-            self.commit(u'Added default view for root object')
+            self.commit('Added default view for root object')
 
     def install_products(self):
         return install_products(self.getApp())
@@ -370,7 +320,7 @@ class AppInitializer(object):
             delattr(app, '_standard_objects_have_been_added')
         if getattr(app, '_initializer_registry', None) is not None:
             delattr(app, '_initializer_registry')
-        transaction.get().note(u'Removed unused application attributes.')
+        transaction.get().note('Removed unused application attributes.')
         transaction.commit()
 
 
