@@ -14,10 +14,6 @@
 import base64
 import logging
 
-from six import PY3
-from six import binary_type
-from six import text_type
-
 import transaction
 from Acquisition import aq_inner
 from Acquisition import aq_parent
@@ -68,16 +64,16 @@ def recordMetaData(object, request):
         else:
             auth_path = '/'.join(auth_folder.getPhysicalPath()[1:-1])
         user_id = auth_user.getId()
-        user_id = safe_unicode(user_id) if user_id else u'None'
+        user_id = safe_unicode(user_id) if user_id else 'None'
         T.setUser(user_id, safe_unicode(auth_path))
 
 
 def safe_unicode(value):
-    if isinstance(value, text_type):
+    if isinstance(value, str):
         return value
-    elif isinstance(value, binary_type):
+    elif isinstance(value, bytes):
         try:
-            value = text_type(value, 'utf-8')
+            value = str(value, 'utf-8')
         except UnicodeDecodeError:
             value = value.decode('utf-8', 'replace')
     return value
@@ -89,8 +85,7 @@ def basic_auth_encode(user, password=None):
     if password is not None:
         value = value + ':' + password
     header = b'Basic ' + base64.b64encode(value.encode('latin-1'))
-    if PY3:
-        header = header.decode('latin-1')
+    header = header.decode('latin-1')
     return header
 
 
@@ -102,7 +97,6 @@ def basic_auth_decode(token):
         return None
     value = token.split()[-1]  # Strip 'Basic '
     plain = base64.b64decode(value)
-    if PY3:
-        plain = plain.decode('latin-1')
+    plain = plain.decode('latin-1')
     user, password = plain.split(':', 1)  # Split at most once
     return (user, password)
